/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2008 Bull S.A.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 * --------------------------------------------------------------------------
 * $Id: ILauncher.java 4389 2008-12-15 13:48:57Z alitokmen $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.launcher;

import java.util.List;
import java.util.Properties;

import org.osgi.framework.BundleException;

/**
 * Provide a generic and customizable launcher for felix.
 */
public interface ILauncher {

    /**
     * Set the list of bundles which must be started with the framework.
     * @param configurationFile A properties file that contains all bundles.
     *        Each file entries associate a start level with a list of bundles.
     *        Example : start.level.1
     *        org.apache.felix:org.apache.felix.shell:1.0.1, \...
     */
    void setAutoloadConfigurationFile(Properties configurationFile);

    /**
     * Set a custom configuration for felix. This must be equivalent to the
     * config.properies file in the standard felix distribution. If no
     * configuration is set, a default one is provided.
     * @param config The custom configuration
     */
    void setConfigProperties(Properties config);

    /**
     * Exclude a set of bundle from the auto started list. Each entries match
     * the pattern <groupid>:<artifactid>.
     * @param excludedBundles The list of excluded bundles.
     */
    void setExcludedBundles(List<String> excludedBundles);

    /**
     * Start Felix gateway.
     * @throws BundleException Thrown if felix cannot start.
     */
    void start() throws BundleException;

    /**
     * Stop Felix gateway.
     * @throws BundleException Thrown if an error occurs during felix stopping.
     */
    void stop() throws BundleException;

    /**
     * Set the root path of Maven repository. It defines where the auto loaded
     * bundles are located.
     * @param repositoryPath The repository path.
     */
    void setMavenRepositoryRoot(String repositoryPath);

    /**
     * Add specific configuration for felix launching.
     */
    void init();

    /**
     * Set the bundle cache directory.
     * @param cacheDirectory Path the the cache directory.
     */
    void setFelixCacheDirectory(String cacheDirectory);

    /**
     * For cleaning felix bundle cache.
     */
    void forceCacheCleanup();
}
